###########################################################################
#
# This software is governed by a license. See
# LICENSE.txt for the terms of this license.
#
###########################################################################
"""
$Id: lang.py,v 1.1.1.1 2004/12/13 21:06:46 dreamcatcher Exp $
"""
import os
import re
import glob
import normalizer
import normalizer.registry

class LangNormalizer:

    def __init__(self, language, lst):
        self._n = normalizer.Normalizer(lst)
        self._language = language

    def getLanguage(self):
        return self._language

    def process(self, words):
        return self._n.normalize(words)

    def __repr__(self):
        return "%s (%s)" % (self.__class__.__name__,
                            self.getLanguage())

    def getTable(self):
        return self._n.getTable()

lang_reg = re.compile('#\s*language\s*=\s*([\w]+)')
enc_reg = re.compile('#\s*encoding\s*=\s*([\w\-]+)')

class FileNormalizer(LangNormalizer):

    def __init__(self, filename):
        assert isinstance(filename, basestring)
        lst, language = self.readNormalizer(filename)
        LangNormalizer.__init__(self, language, lst)

    def readNormalizer(self, filename):
        """Read a stopword file (line-by-line) from disk.
        'fname' is either relative to this file
        or has an absolute path.
        """

        d = {}
        language = None
        encoding = None

        lines = open(filename).readlines()

        lst = []

        for l in lines:
            if not l.strip(): continue

            mo = lang_reg.match(l)
            if mo:
                language = mo.group(1)
                continue

            mo = enc_reg.match(l)
            if mo:
                encoding = mo.group(1)
                continue

            if l.startswith('#'):
                continue

            fields = l.split()
            assert len(fields) == 2

            k = unicode(fields[0], encoding)
            v = unicode(fields[1], encoding)

            lst.append((k,v))

        return lst, language

LanguageRegistry = registry = normalizer.registry.Registry('Languages')

cur_dir = os.path.dirname(__file__)
input_files = glob.glob(os.path.join(cur_dir, 'data', 'langs', '*.txt'))

for f in input_files:
    n = FileNormalizer(f)
    registry.register(n.getLanguage(), n)

def normalize(words, langs):
    for lang in langs:
        n = registry.get(lang)
        if n is not None:
            words = n.process(words)
    return words
